#
# spec file for package python-jedi
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# Compiled file tests only work on particular architectures and only run on python 3.4
%bcond_with tests
Name:           python-jedi
Version:        0.13.2
Release:        2.2
Summary:        An autocompletion tool for Python
License:        MIT AND Python-2.0
Group:          Development/Languages/Python
URL:            https://github.com/davidhalter/jedi
Source0:        https://files.pythonhosted.org/packages/source/j/jedi/jedi-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-parso >= 0.3.0
BuildArch:      noarch
%if %{with tests}
# Test requirements
BuildRequires:  %{python_module colorama}
BuildRequires:  %{python_module docopt}
BuildRequires:  %{python_module numpydoc}
BuildRequires:  %{python_module parso >= 0.3.0}
BuildRequires:  %{python_module pytest >= 2.3.5}
BuildRequires:  %{python_module pytest-cache}
BuildRequires:  python2-typing
BuildRequires:  python3-tox
# do not require python3-typing for python >= 3.5
%if 0%{?suse_version} <= 1320
BuildRequires:  python3-typing
%endif
%endif
%python_subpackages

%description
Jedi is a static analysis tool for Python that can be used in
IDEs/editors. Its focus is autocompletion and static
analysis.

Jedi has support for two different goto functions. It’s possible to
search for related names and to list all names in a Python file and
infer them. Jedi understands docstrings and you can use Jedi
autocompletion in your REPL as well.

Jedi uses an API to connect with IDEs. There is a reference
implementation as a VIM plugin which uses Jedi's autocompletion.

%prep
%setup -q -n jedi-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with tests}
%check

export PYTHONDONTWRITEBYTECODE=1
export LANG="en_US.UTF-8"
pushd docs
# we don't care about the speed, just that it works
tox -e py%{python3_version_nodots} --sitepackages --skip-missing-interpreters
popd
%endif

%files %{python_files}
%doc AUTHORS.txt CHANGELOG.rst README.rst
%license LICENSE.txt
%{python_sitelib}/jedi-%{version}-py*.egg-info
%{python_sitelib}/jedi/

%changelog
* Sun Jan  6 2019 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.13.2:
  * Fixed a bug that led to Jedi spawning a lot of subprocesses.
* Thu Oct 11 2018 toddrme2178@gmail.com
- update to version 0.13.1
  * Bugfixes, because tensorflow completions were still slow.
- update to version 0.13.0
  * A small release. Some bug fixes.
  * Remove Python 3.3 support. Python 3.3 support has been dropped by the Python
    foundation.
  * Default environments are now using the same Python version as the Python
    process. In 0.12.x, we used to load the latest Python version on the system.
  * Added ``include_builtins`` as a parameter to usages.
  * ``goto_assignments`` has a new ``follow_builtin_imports`` parameter that
    changes the previous behavior slightly.
- Remove test_requrements.patch, no longer needed
* Mon Jul  2 2018 arun@gmx.de
- specfile:
  * require parso >= 0.3.0
  * remove python-devel requirement
- update to version 0.12.1:
  * This release forces you to upgrade parso. If you don't, nothing
    will work anymore. Otherwise changes should be limited to bug
    fixes. Unfortunately Jedi still uses a few internals of parso that
    make it hard to keep compatibility over multiple releases. Parso
    >=0.3.0 is going to be needed.
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 0.12.0
  * Virtualenv/Environment support
  * F-String Completion/Goto Support
  * Cannot crash with segfaults anymore
  * Cleaned up import logic
  * Understand async/await and autocomplete it (including async generators)
  * Better namespace completions
  * Passing tests for Windows (including CI for Windows)
  * Remove Python 2.6 support
- Update to version 0.11.1
  * Parso update - the caching layer was broken
  * Better usages - a lot of internal code was ripped out and improved.
- Remove upstream-included test_requrements.patch
- Add new test_requrements.patch to avoid limit on pytest version.
- Disable tests, they don't work in most situations.
* Fri Nov 10 2017 mimi.vx@gmail.com
- fix requires
* Fri Nov 10 2017 mimi.vx@gmail.com
- fix tests to run on current python3
- added test_requrements.patch to allow newer versions of python-parso
* Fri Nov 10 2017 mimi.vx@gmail.com
- fix test conditions
* Tue Sep 26 2017 arun@gmx.de
- specfile:
  * require python-parso
  * require python-numpydoc for tests
- update to version 0.11.0:
  * Split Jedi's parser into a separate project called parso.
  * Avoiding side effects in REPL completion.
  * Numpy docstring support should be much better.
  * Moved the settings.*recursion* away, they are no longer usable.
* Mon Jun 19 2017 sebix+novell.com@sebix.at
- only require python3-typing if necessary
* Fri Apr 28 2017 jengelh@inai.de
- Grammatical corrections to description.
  Replace historic focus by current focus.
* Thu Apr 27 2017 toddrme2178@gmail.com
- Fix license.
* Thu Apr 27 2017 toddrme2178@gmail.com
- Disable tests on non-x86/x86_64 platforms.
* Tue Apr 25 2017 toddrme2178@gmail.com
- Update to version 0.10.2
  * Python Packaging sucks. Some files were not included in 0.10.1.
- Update to version 0.10.1
  * Fixed a few very annoying bugs.
  * Prepared the parser to be factored out of Jedi.
- Update to version 0.10.0
  * Actual semantic completions for the complete Python syntax.
  * Basic type inference for ``yield from`` PEP 380.
  * PEP 484 support (most of the important features of it).
  * Added ``get_line_code`` to ``Definition`` and ``Completion``
    objects.
  * Completely rewritten the type inference engine.
  * A new and better parser for (fast) parsing diffs of Python
    code.
- Implement single-spec version
* Thu Nov  5 2015 toddrme2178@gmail.com
- Fix tests
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 0.9.0:
  * The import logic has been rewritten to look more like Python's.
    There is now an Evaluator.modules import cache, which resembles
    sys.modules.
  * Integrated the parser of 2to3. This will make refactoring
    possible. It will also be possible to check for error messages
    (like compiling an AST would give) in the future.
  * With the new parser, the evaluation also completely changed.
    It's now simpler and more readable.
  * Completely rewritten REPL completion.
  * Added jedi.names, a command to do static analysis. Thanks to
    that sourcegraph guys for sponsoring this!
  * Alpha version of the linter.
- remove "-final0" appended to source version
- add python-unittest2 as a test dependency for SLE11
- skip failing tests in test_integration_import.py
* Wed Aug 13 2014 toddrme2178@gmail.com
- Update to version 0.8.1
  * Bugfix release, the last release forgot to include files that
    improve autocompletion for builtin libraries. Fixed.
- Update to version 0.8.0
  * Memory Consumption for compiled modules (e.g. builtins, sys)
    has been reduced drastically. Loading times are down as well
    (it takes basically as long as an import).
  * REPL completion is starting to become usable.
  * Various small API changes. Generally this released focuses on
    stability and refactoring of internal APIs.
  * Introducing operator precedence, which makes calculating
    correct Array indices and __getattr__ strings possible.
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 0.7.0
  * switched from LGPL to MIT license
  * added an Interpreter class to the API to make autocompletion
    in REPL possible.
  * added autocompletion support for namespace packages
  * add sith.py, a new random testing method
- Change License to MIT
- Drop old python3 stuff
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Aug 15 2013 mvyskocil@suse.com
- update to 0.6.0
  * Created find_module helper to handle compatibility with python 3.3
  * Fixed caching issues
  * More robust source encoding detection
  * Improved documentantion
  * and lot of bugfixes
- drop pre-checkin.sh
- drop a dependency on rpmbuild > 4.10, we don't need no ~ in version
* Thu May  9 2013 mvyskocil@suse.com
- package python3 variant via pre_checkin.sh
* Thu May  2 2013 mvyskocil@suse.com
- first packaging of jedi 0.5b5 for SUSE
